/*
    Author: Andy Kirby, Email: andy@kirbyand.co.uk, Date: 16/12/2010
    Contributors: 
    Licensing GPL V3 (http://www.gnu.org/licenses/quick-guide-gplv3.html).

    Script to create a PMT (EMI 9954KA) to 35mm x 35mm square aperture for waveguide coupling.

    Thanks to Dr John Mcmillan,(j.e.mcmillan@sheffield.ac.uk) 
    Department of Physics & Astronomy,
    University of Sheffield
*/

/* Global Variables */
// Parameters to change the part
h = 15;         // overall height of coupler
odcoup = 55;    // OD Radius of coupler
odpmt = 51;     // OD Radius of PMT
wgxy = 35;	  // Waveguide xy size, nb square
smooth = 32;	  // smoothness of the circle, how many facets a circle is made from

// Do not change, precalculated factors to aid layout.
rcoup = odcoup / 2;
rpmt = odpmt / 2;
wgcentre = wgxy / 2;
wgdepth = 2*( h / 3);
pmtdepth = h / 3;


/* Main or start function basicaly do it */
render (convexity = 1) {
   pmtcoupler();
}


/*
   module to create the coupler as the difference between solids describing the parts
*/
module pmtcoupler()
{

   difference(){   
      coupler();
      translate(v= [-wgcentre, -wgcentre, 0]) wgend();
      translate(v = [0, 0, wgdepth]) pmtend();
   }
}


/*
   module to create the solid coupler cylinder
*/
module coupler()
{
   cylinder(h=h, r1=rcoup, r2=rcoup, center=false, $fn = smooth);   
}

/*
   module to model the solid end of the pmt tube
*/
module pmtend()
{
   cylinder(h=pmtdepth, r1=rpmt, r2=rpmt, center=false, $fn = smooth);   
}

/*
   module to model the solid end of the wave guide.
   N.B. Square cut and polished, xy centered
*/
module wgend()
{
   cube(size = [wgxy,wgxy,h], center=false);
}

